==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ASynchronizedModifier.h <==
// public final class soot.jimple.parser.node.ASynchronizedModifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fd17124c635dac90 soot_jimple_parser_node_ASynchronizedModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_ASynchronizedModifier_H_
#define _JC_soot_jimple_parser_node_ASynchronizedModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TSynchronized$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ASynchronizedModifier$sub_refs	_jc_soot_jimple_parser_node_ASynchronizedModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ASynchronizedModifier$sub_nonrefs	_jc_soot_jimple_parser_node_ASynchronizedModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASynchronizedModifier$refs	_jc_soot_jimple_parser_node_ASynchronizedModifier$refs;
typedef struct _jc_soot_jimple_parser_node_ASynchronizedModifier$nonrefs	_jc_soot_jimple_parser_node_ASynchronizedModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object	_jc_soot_jimple_parser_node_ASynchronizedModifier$object;

typedef const struct _jc_soot_jimple_parser_node_ASynchronizedModifier$vmethods	_jc_soot_jimple_parser_node_ASynchronizedModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ASynchronizedModifier$vtable	_jc_soot_jimple_parser_node_ASynchronizedModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_ASynchronizedModifier$vtype	_jc_soot_jimple_parser_node_ASynchronizedModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ASynchronizedModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *);
extern void _jc_soot_jimple_parser_node_ASynchronizedModifier$method$_init$1c082dae94ff1238(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_soot_jimple_parser_node_TSynchronized$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ASynchronizedModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ASynchronizedModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *);
extern struct _jc_soot_jimple_parser_node_TSynchronized$object *_jc_soot_jimple_parser_node_ASynchronizedModifier$method$getSynchronized$e1bbb9602134d92f(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *);
extern void _jc_soot_jimple_parser_node_ASynchronizedModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ASynchronizedModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ASynchronizedModifier$method$setSynchronized$784486fb92365556(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_soot_jimple_parser_node_TSynchronized$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ASynchronizedModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ASynchronizedModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ASynchronizedModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ASynchronizedModifier$method_info$getSynchronized$e1bbb9602134d92f;
extern _jc_method _jc_soot_jimple_parser_node_ASynchronizedModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ASynchronizedModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ASynchronizedModifier$method_info$setSynchronized$784486fb92365556;
extern _jc_method _jc_soot_jimple_parser_node_ASynchronizedModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *);
	struct _jc_soot_jimple_parser_node_TSynchronized$object	*(*getSynchronized$e1bbb9602134d92f)(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setSynchronized$784486fb92365556)(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_soot_jimple_parser_node_TSynchronized$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_ASynchronizedModifier$vmethods	soot_jimple_parser_node_ASynchronizedModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ASynchronizedModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TSynchronized$object	*__5fsynchronized__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$refs {
    _jc_soot_jimple_parser_node_ASynchronizedModifier$sub_refs	soot_jimple_parser_node_ASynchronizedModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_ASynchronizedModifier$sub_nonrefs	soot_jimple_parser_node_ASynchronizedModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object {
	_jc_soot_jimple_parser_node_ASynchronizedModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ASynchronizedModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_ASynchronizedModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ASynchronizedModifier$vtype _jc_soot_jimple_parser_node_ASynchronizedModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ASynchronizedModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ASynchronizedModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_ASynchronizedModifier_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ASynchronizedModifier.h <==
// public final class soot.jimple.parser.node.ASynchronizedModifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fd17124c635dac90 soot_jimple_parser_node_ASynchronizedModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_ASynchronizedModifier_H_
#define _JC_soot_jimple_parser_node_ASynchronizedModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TSynchronized$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ASynchronizedModifier$sub_refs	_jc_soot_jimple_parser_node_ASynchronizedModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ASynchronizedModifier$sub_nonrefs	_jc_soot_jimple_parser_node_ASynchronizedModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASynchronizedModifier$refs	_jc_soot_jimple_parser_node_ASynchronizedModifier$refs;
typedef struct _jc_soot_jimple_parser_node_ASynchronizedModifier$nonrefs	_jc_soot_jimple_parser_node_ASynchronizedModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object	_jc_soot_jimple_parser_node_ASynchronizedModifier$object;

typedef const struct _jc_soot_jimple_parser_node_ASynchronizedModifier$vmethods	_jc_soot_jimple_parser_node_ASynchronizedModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ASynchronizedModifier$vtable	_jc_soot_jimple_parser_node_ASynchronizedModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_ASynchronizedModifier$vtype	_jc_soot_jimple_parser_node_ASynchronizedModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ASynchronizedModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASynchronizedModifier$method$_init$1c082dae94ff1238(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_soot_jimple_parser_node_TSynchronized$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ASynchronizedModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ASynchronizedModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TSynchronized$object *_jc_soot_jimple_parser_node_ASynchronizedModifier$method$getSynchronized$e1bbb9602134d92f(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASynchronizedModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASynchronizedModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASynchronizedModifier$method$setSynchronized$784486fb92365556(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_soot_jimple_parser_node_TSynchronized$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ASynchronizedModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ASynchronizedModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ASynchronizedModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ASynchronizedModifier$method_info$getSynchronized$e1bbb9602134d92f;
extern _jc_method _jc_soot_jimple_parser_node_ASynchronizedModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ASynchronizedModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ASynchronizedModifier$method_info$setSynchronized$784486fb92365556;
extern _jc_method _jc_soot_jimple_parser_node_ASynchronizedModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TSynchronized$object	*(*getSynchronized$e1bbb9602134d92f)(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setSynchronized$784486fb92365556)(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *, struct _jc_soot_jimple_parser_node_TSynchronized$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_ASynchronizedModifier$vmethods	soot_jimple_parser_node_ASynchronizedModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ASynchronizedModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TSynchronized$object	*__5fsynchronized__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$refs {
    _jc_soot_jimple_parser_node_ASynchronizedModifier$sub_refs	soot_jimple_parser_node_ASynchronizedModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_ASynchronizedModifier$sub_nonrefs	soot_jimple_parser_node_ASynchronizedModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ASynchronizedModifier$object {
	_jc_soot_jimple_parser_node_ASynchronizedModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ASynchronizedModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_ASynchronizedModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ASynchronizedModifier$vtype _jc_soot_jimple_parser_node_ASynchronizedModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ASynchronizedModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ASynchronizedModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_ASynchronizedModifier_H_ */
